-- Localization
local L = GenderTooltip_LocalizationTable;

-- AddOn options
GenderTooltip_Options = {
	Enabled = true,
	TextColoring = false,
	Colors = {
		None = "FFFFFF",
		Male = "69CCF0",
		Female = "F58CBA",
	};
};

-- Utility function to convert RGB to their hex equivelents
local function RGBToHex(r, g, b)
	r = tonumber(r);
	g = tonumber(g);
	b = tonumber(b);
	if r < 0 then
		r = 0;
	elseif r > 255 then
		while r > 255 do
			r = r - 255;
		end
	end
	if g < 0 then
		g = 0;
	elseif g > 255 then
		while g > 255 do
			g = g - 255;
		end
	end
	if b < 0 then
		b = 0;
	elseif b > 255 then
		while b > 255 do
			b = b - 255;
		end
	end
	return string.format("%02X%02X%02X", r, g, b)
end

-- Handler function for the slash commands
local function GenderTooltip_SlashCommand(msg, editBox)
	msg = msg:lower();
	local args = {};
	for word in msg:gmatch("[^%s]+") do
		table.insert(args, word);
	end

	if args[1] then
		if args[1] == L["on"] then
			GenderTooltip_Options.Enabled = true;
		elseif args[1] == L["off"] then
			GenderTooltip_Options.Enabled = false;
		elseif args[1] == L["color"] then
			if args[2] == L["on"] then
				GenderTooltip_Options.TextColoring = true;
			elseif args[2] == L["off"] then
				GenderTooltip_Options.TextColoring = false;
			elseif args[2] == L["set"] then
				local gender = "None";
				if args[3] == L["Male"]:lower() then
					gender = "Male";
				elseif args[3] == L["Female"]:lower() then
					gender = "Female";
				end

				if not args[4] or not args[5] or not args[6] then
					print(L["Error_Color_set"]);
				else
					GenderTooltip_Options.Colors[gender] = RGBToHex(args[4], args[5], args[6]);
				end
			else
				print(L["Error_Color"]);
			end
		else
			print(L["Error_Unk_Args"]);
		end
	else
		print(L["Error_Usage"]);
	end
end
SlashCmdList["GENDERTOOLTIP"] = GenderTooltip_SlashCommand;
SLASH_GENDERTOOLTIP1 = "/gto";
SLASH_GENDERTOOLTIP2 = "/gtto";
SLASH_GENDERTOOLTIP3 = "/gendertooltipoptions";

-- Handle when the user mouses over a unit, replacing the "Level" line.
local function GenderTooltip_OnSetUnit(self)
	if GenderTooltip_Options.Enabled == false then
		return nil;
	end

	local genders = {"", L["Male"], L["Female"]};
	local gender_options = {"None", "Male", "Female"};
	local unit = select(2, self:GetUnit());
	if not unit then
		return nil;
	end

	if UnitIsPlayer(unit) then
		for i = 2, self:NumLines() do
			if _G["GameTooltipTextLeft"..i]:GetText():find("^" .. L["Level"]) then
				-- Bugfix from 'Richard' on Curse.com for level display
				-- "Made a few changes to accomodate opposite faction players who's level shows up as ??."
				local level = UnitLevel(unit);
				if level == -1 then
					level = "??";
				end
				local gender = genders[UnitSex(unit)];
				if GenderTooltip_Options.TextColoring == true then
					gender = "|cFF"..GenderTooltip_Options.Colors[gender_options[UnitSex(unit)]]..gender.."|r";
				end
				local race = UnitRace(unit);
				local class = UnitClass(unit);
				local txt = L["Level"].." "..level.." "..gender;

				if race ~= nil then
					txt = txt.." "..race;
				end
				if class ~= nil then
					txt = txt.." "..class;
				end;

				_G["GameTooltipTextLeft"..i]:SetText(txt.." ("..L["Player"]..")");

				self:Show();
				break;
			end
		end
	end
end
GameTooltip:HookScript("OnTooltipSetUnit", GenderTooltip_OnSetUnit);
